==> openshift-serverless-logic-1.26.0-src.zip: openshift-serverless-logic-1.26.0.GA-src/org.kie.kogito-kogito-apps-1.30.0.Final/ui-packages/packages/workflow-form/src/envelope/tests/WorkflowFormEnvelopeViewDriver.test.ts <==
/*
 * Copyright 2022 Red Hat, Inc. and/or its affiliates.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

import {
  MessageBusClientApi,
  RequestPropertyNames
} from '@kogito-tooling/envelope-bus/dist/api';
import { WorkflowFormChannelApi } from '../../api';
import { WorkflowFormEnvelopeViewDriver } from '../WorkflowFormEnvelopeViewDriver';
import { MockedMessageBusClientApi } from './mocks/Mocks';

let channelApi: MessageBusClientApi<WorkflowFormChannelApi>;
let requests: Pick<
  WorkflowFormChannelApi,
  RequestPropertyNames<WorkflowFormChannelApi>
>;
let driver: WorkflowFormEnvelopeViewDriver;

describe('WorkflowFormEnvelopeViewDriver tests', () => {
  beforeEach(() => {
    jest.clearAllMocks();
    channelApi = new MockedMessageBusClientApi();
    requests = channelApi.requests;
    driver = new WorkflowFormEnvelopeViewDriver(channelApi);
  });

  it('doSubmit', () => {
    const formJSON = {
      something: 'something'
    };
    driver.startWorkflowCloudEvent(formJSON);

    expect(requests.workflowForm__startWorkflowCloudEvent).toHaveBeenCalledWith(formJSON);
  });

  it('start custom workflow',()=>{
    driver.startWorkflowRest({name:"John"}, 'http://localhost:8080/test');
    expect(requests.workflowForm__startWorkflowRest).toHaveBeenCalledWith({name:"John"}, 'http://localhost:8080/test');
  })
});

==> openshift-serverless-logic-1.30.0-src.zip: openshift-serverless-logic-1.30.0.GA-src/org.kie.kogito-kogito-apps-1.40.0.Final/ui-packages/packages/workflow-form/src/envelope/tests/WorkflowFormEnvelopeViewDriver.test.ts <==
/*
 * Copyright 2022 Red Hat, Inc. and/or its affiliates.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

import {
  MessageBusClientApi,
  RequestPropertyNames
} from '@kogito-tooling/envelope-bus/dist/api';
import { WorkflowFormChannelApi } from '../../api';
import { WorkflowFormEnvelopeViewDriver } from '../WorkflowFormEnvelopeViewDriver';
import { MockedMessageBusClientApi } from './mocks/Mocks';

let channelApi: MessageBusClientApi<WorkflowFormChannelApi>;
let requests: Pick<
  WorkflowFormChannelApi,
  RequestPropertyNames<WorkflowFormChannelApi>
>;
let driver: WorkflowFormEnvelopeViewDriver;

describe('WorkflowFormEnvelopeViewDriver tests', () => {
  beforeEach(() => {
    jest.clearAllMocks();
    channelApi = new MockedMessageBusClientApi();
    requests = channelApi.requests;
    driver = new WorkflowFormEnvelopeViewDriver(channelApi);
  });

  it('start custom workflow', () => {
    driver.startWorkflow('http://localhost:8080/test', { name: 'John' });
    expect(requests.workflowForm__startWorkflow).toHaveBeenCalledWith(
      'http://localhost:8080/test',
      { name: 'John' }
    );
  });
});
